Removes all objects from the internal cache environment so that subsequent diagnostic calls recompute their statistics.
See also
cachedTest() for invoking diagnostics with memoisation.
Removes all objects from the internal cache environment so that subsequent diagnostic calls recompute their statistics.
cachedTest() for invoking diagnostics with memoisation.