Runs selected diagnostics for a single model and returns a tidy data frame of test statistics and p-values.
Usage
compareTestResults(model, data = NULL, tests = c("white", "breusch_pagan"))Runs selected diagnostics for a single model and returns a tidy data frame of test statistics and p-values.
compareTestResults(model, data = NULL, tests = c("white", "breusch_pagan"))