Maintains a registry of diagnostic functions that can be called by
runHeteroTests() and runDiagnostics(). Users can register
custom diagnostics via registerDiagnostic().
Maintains a registry of diagnostic functions that can be called by
runHeteroTests() and runDiagnostics(). Users can register
custom diagnostics via registerDiagnostic().