Perform Spread-Level test
performSpreadLevelTest.RdTests the slope of log(|residuals|) on log(fitted).
Details
A slope near 0 indicates constant variance. A significant slope suggests a power transformation may stabilize the spread.
performSpreadLevelTest.RdTests the slope of log(|residuals|) on log(fitted).
A slope near 0 indicates constant variance. A significant slope suggests a power transformation may stabilize the spread.