Register a custom diagnostic
registerDiagnostic.RdAdds a function to the diagnostics registry so it can be called by runHeteroTests.
Examples
custom <- function(model, data) list(statistic = 0)
registerDiagnostic("custom", custom)
registerDiagnostic.RdAdds a function to the diagnostics registry so it can be called by runHeteroTests.
custom <- function(model, data) list(statistic = 0)
registerDiagnostic("custom", custom)